@@ -1,6 +1,6 @@
 import configparser
 from datetime import datetime, timedelta
-from typing import Optional
+from typing import Self
 
 from . import ConfigurationError, Wakeup
 
@@ -12,7 +12,7 @@ class Periodic(Wakeup):
     """
 
     @classmethod
-    def create(cls, name: str, config: configparser.SectionProxy) -> "Periodic":
+    def create(cls: type[Self], name: str, config: configparser.SectionProxy) -> Self:
         try:
             kwargs = {config["unit"]: float(config["value"])}
             return cls(name, timedelta(**kwargs))
@@ -23,5 +23,5 @@ class Periodic(Wakeup):
         Wakeup.__init__(self, name)
         self._delta = delta
 
-    def check(self, timestamp: datetime) -> Optional[datetime]:
+    def check(self, timestamp: datetime) -> datetime | None:
         return timestamp + self._delta
