@@ -6,4 +6,6 @@ def is_aware(dt: datetime) -> bool:
 
 
 def to_tz_unaware(dt: datetime, tz: tzinfo | None) -> datetime:
-    return dt.astimezone(tz).replace(tzinfo=None)
+    """Convert a datetime to the given timezone and return a naive datetime (no tzinfo)."""
+    dt = dt.replace(tzinfo=tz) if dt.tzinfo is None else dt.astimezone(tz)
+    return dt.replace(tzinfo=None)
